# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'GetRouterConfigurationRouterResult',
]

@pulumi.output_type
class GetRouterConfigurationRouterResult(dict):
    def __init__(__self__, *,
                 platform: str,
                 router_type_identifier: str,
                 software: str,
                 vendor: str,
                 xslt_template_name: str,
                 xslt_template_name_for_mac_sec: str):
        """
        :param str platform: Router platform
        :param str router_type_identifier: ID of the Router Type. For example: `CiscoSystemsInc-2900SeriesRouters-IOS124`
        :param str software: Router operating system
        :param str vendor: Router vendor
        :param str xslt_template_name: Router XSLT Template Name
        """
        pulumi.set(__self__, "platform", platform)
        pulumi.set(__self__, "router_type_identifier", router_type_identifier)
        pulumi.set(__self__, "software", software)
        pulumi.set(__self__, "vendor", vendor)
        pulumi.set(__self__, "xslt_template_name", xslt_template_name)
        pulumi.set(__self__, "xslt_template_name_for_mac_sec", xslt_template_name_for_mac_sec)

    @property
    @pulumi.getter
    def platform(self) -> str:
        """
        Router platform
        """
        return pulumi.get(self, "platform")

    @property
    @pulumi.getter(name="routerTypeIdentifier")
    def router_type_identifier(self) -> str:
        """
        ID of the Router Type. For example: `CiscoSystemsInc-2900SeriesRouters-IOS124`
        """
        return pulumi.get(self, "router_type_identifier")

    @property
    @pulumi.getter
    def software(self) -> str:
        """
        Router operating system
        """
        return pulumi.get(self, "software")

    @property
    @pulumi.getter
    def vendor(self) -> str:
        """
        Router vendor
        """
        return pulumi.get(self, "vendor")

    @property
    @pulumi.getter(name="xsltTemplateName")
    def xslt_template_name(self) -> str:
        """
        Router XSLT Template Name
        """
        return pulumi.get(self, "xslt_template_name")

    @property
    @pulumi.getter(name="xsltTemplateNameForMacSec")
    def xslt_template_name_for_mac_sec(self) -> str:
        return pulumi.get(self, "xslt_template_name_for_mac_sec")


